@@ -1,6 +1,6 @@
 package IRC::Toolkit::ISupport;
 {
-  $IRC::Toolkit::ISupport::VERSION = '0.084000';
+  $IRC::Toolkit::ISupport::VERSION = '0.084001';
 }
 use 5.10.1;
 use Carp 'confess';
@@ -179,7 +179,7 @@ sub parse_isupport {
 
   sub as_string {
     my ($self) = @_;
-    join ',', map { join '', @$_ }
+    join ',', map {; join '', @$_ }
       $self->list,
       $self->always,
       $self->whenset,
@@ -271,6 +271,10 @@ sub parse_isupport {
 }
 
 
+print
+  qq[<Gilded> "BREAKING: NH MAN HEARS ABOUT CLIMATE CHANGE, ],
+  qq[CLEARS FIVE HUNDRED ACRES FOR COCA PLANTATION"\n]
+unless caller;
 1;
 
 =pod
